Returns the directory estatr uses for cached metadata and pagination
checkpoints. Override with options(estatr.cache_dir = "...").
Returns the directory estatr uses for cached metadata and pagination
checkpoints. Override with options(estatr.cache_dir = "...").